@@ -137,12 +137,12 @@ def kaggle(data='tabular-playground-series-mar-2021', output='/kaggle/input'):
     subprocess.call('pip install -q --upgrade --force-reinstall --no-deps kaggle kaggle-cli', shell=True)
     subprocess.call('mkdir -p /root/.kaggle', shell=True)
     os.chdir('/root/.kaggle')
-    print('Upload your kaggle API token')
-    files.upload()
-    subprocess.call('chmod 600 /root/.kaggle/kaggle.json', shell=True)
-    subprocess.call('mkdir -p /kaggle/input', shell=True)
-    subprocess.call('mkdir -p /kaggle/output', shell=True)
-    os.chdir('/kaggle/input')
+    if 'kaggle.json' not in os.listdir('/root/.kaggle'):
+        print('Upload your kaggle API token')
+        files.upload()
+        subprocess.call('chmod 600 /root/.kaggle/kaggle.json', shell=True)
+    subprocess.call(f'mkdir -p {output}', shell=True)
+    os.chdir(f'{output}')
     subprocess.call(f'kaggle competitions download -c {data}', shell=True)
     subprocess.call(f'7z x {data}.zip -o{output}', shell=True)
     print(f'\nUnzipped {data}.zip to {output}.')
